# Generated by Django 1.9.13 on 2018-01-06 13:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('leprikon', '0006_discount_periods'),
    ]

    operations = [
        migrations.AddField(
            model_name='subject',
            name='bill_print_setup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='leprikon.PrintSetup', verbose_name='payment print setup'),
        ),
        migrations.AddField(
            model_name='subjecttype',
            name='bill_print_setup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='leprikon.PrintSetup', verbose_name='payment print setup'),
        ),
    ]
