
html {
    min-height: 100%;
}

.navbar {
    margin-bottom: 0;
}

#header {
    padding-top: 10px;
    padding-bottom: 10px;
    border-bottom: 3px solid;
}

#body {
    position: relative;
    padding-top: 15px;
    padding-bottom: 300px;
    font-size: 16px;
}

#content, #sidebar {
    padding-bottom: 30px;
}

#sidebar .box {
    margin-bottom: 0;
}

#leprikon {
    position: absolute;
    bottom: 0;
    display: block;
    width: 150px;
    height: 300px;
    background-image: url(../img/leprikon-kuk-l.png);
    background-size: 150px 300px;
    background-repeat: no-repeat;
}

#leprikon span {
    display: none;
}

.box {
    padding: 0px;
    margin-top: 15px;
    margin-bottom: 35px;
}

.box-header {
    clear: both;
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
    border: 2px solid;
    padding: 3px 10px;
    font-size: 18px;
}

.box-header .tag {
    display: inline-block;
    border: 1px solid;
    border-radius: 5px;
    padding: 1px 5px;
}

.box-header small {
    margin-left: 15px;
}

.box-header a.btn {
    float: right;
    margin-left: 5px;
}

.box-content {
    padding: 10px;
    border-left: 2px solid;
    border-right: 2px solid;
    border-bottom: 2px solid;
    margin-bottom: 10px;
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}

.box-header:after,
.box-content:after {
    content: '';
    display: block;
    clear: both;
}

.box-content label {
    text-align: right;
}

.box-content .row {
    margin-bottom: 5px;
}

.clear {
    clear: both;
}

h1 {
    font-size: 28px;
    border-radius: 10px;
    padding: 10px;
}

h2 {
    font-size: 22px;
}

form .panel,
form .alert {
    margin-bottom: 0;
}

.alert {
    padding: 10px;
}

#messages .alert {
    font-size: 20px;
}

.alert .close {
    top: 0;
    right: 0;
}

.right {
    text-align: right;
}

.btn.right {
    text-align: left;
    float: right;
    margin-bottom: 5px;
}

img.right {
    text-align: left;
    float: right;
    margin-left: 15px;
    margin-bottom: 15px;
}

.form-group label {
    font-weight: normal;
}

.form-group.required > label {
    font-weight: bold;
}

.form-group.required > label:after {
  content:"*"; color:red;
}

input.form-control[type="checkbox"] {
    width: unset;
}

.checkbox input.form-control[type="checkbox"] {
    height: unset;
    position: relative;
    display: unset;
    margin-left: unset;
}

/* do not show radio inputs in multiselect */
.radio input {
    display: none;
}

.list-group .list-group {
    margin-bottom: 0;
    margin-left: 30px;
}

.list-group .list-group .list-group-item {
    padding: 5px 15px;
}

.list-group .list-group .list-group-item:last-child {
    border-bottom: 0;
    border-top-right-radius: 0;
    border-top-left-radius: 0;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}

.clickable {
    cursor: pointer;
}

.hidden {
    display: none;
}

.line-through {
    text-decoration: line-through;
}

.modal {
  text-align: center;
  padding: 0!important;
}

.modal:before {
  content: '';
  display: inline-block;
  height: 80%;
  vertical-align: middle;
  margin-right: -4px; /* Adjusts for spacing */
}

.modal-dialog {
  display: inline-block;
  text-align: left;
  vertical-align: middle;
}

tr.message.notread {
    font-weight: bold;
}

td.message-subject a {
    display: block;
    padding: 3px;
}

.message-details {
    float: right;
    text-align: right;
    margin-left:   30px;
    margin-bottom: 30px;
}

.message-text {
    font-size: 120%;
    padding:   15px;
}

@media print {
    #cms-top,
    #header, #messages, #sidebar,
    #list_filter_form,
    .btn, .btn-group {
        display: none;
    }
    #body {
        padding-top: 0;
        padding-bottom: 0;
    }
    #content {
        width: 17cm;
        font-size: 12px;
    }
    h1 { font-size: 18px; }
    h2 { font-size: 16px; }
    h3 { font-size: 14px; }
    .box-header { font-size: 14px; }
    .box {
        page-break-inside: avoid;
        margin: 5mm 0;
    }
}
